@@ -30,7 +30,7 @@ __all__ = [
     "write_mem",
 ]
 
-__version__ = "4.1"
+__version__ = "4.2"
 
 import argparse
 import inspect
@@ -354,6 +354,13 @@ def main(argv=None, esp=None):
         "image_info", help="Dump headers from an application image"
     )
     parser_image_info.add_argument("filename", help="Image file to parse")
+    parser_image_info.add_argument(
+        "--version",
+        "-v",
+        help="Output format version (1 - legacy, 2 - extended)",
+        choices=["1", "2"],
+        default="1",
+    )
 
     parser_make_image = subparsers.add_parser(
         "make_image", help="Create an application image from binary files"
@@ -399,8 +406,10 @@ def main(argv=None, esp=None):
         "--min-rev",
         "-r",
         help="Minimum chip revision",
-        choices=["0", "1", "2", "3"],
-        default="0",
+        type=int,
+        choices=range(256),
+        metavar="{0, ... 255}",
+        default=0,
     )
     parser_elf2image.add_argument(
         "--secure-pad",
